==> egg-user-model-1.0.0.7-sources.jar: com/bxm/egg/user/properties/CommonProperties.java <==
package com.bxm.egg.user.properties;

import lombok.Data;
import org.springframework.boot.context.properties.ConfigurationProperties;
import org.springframework.stereotype.Component;

/**
 * @author zhaoyadong 2019/3/9 13:41
 * @desc
 */
@Data
@Component
@ConfigurationProperties("common.config")
public class CommonProperties {


    /**
     * 创蓝闪验加密私钥
     */
    private String chuanglanPrivateKey;


    /**
     * 区域编码
     */
    private String locationCode;

    /**
     * 区域名称
     */
    private String locationName;

    /**
     * 极光appKey
     */
    private String jiGuangAppKey = "4f96a04fc41c557beea4a84e";

    /**
     * 极光密钥
     */
    private String jiGuangMasterSecret = "725e661f39c5c21e422f2d87";

    /**
     * 极光一键登录私钥
     */
    private String oneKeySecretKey =
            "MIICeAIBADANBgkqhkiG9w0BAQEFAASCAmIwggJeAgEAAoGBANStYKekQuFUoWcX\n" +
                    "MZLdPhi4qXAc45OiG43WtdUV8V1e1Kn7Bn2bGZGdKF82+JrXNQwr2Kg33LLavtll\n" +
                    "eWBFSJMTeGbP/xtdK7htldM4VdRI5AigNwNroM3/j7gqxkqKqG+1uPpRckujIOkT\n" +
                    "3HcPfAF77o7mDi5gQHT9gaPf3rZPAgMBAAECgYAFZmGN4B3SmtN+Sph3oiZxej7T\n" +
                    "GeitVvBcKZd0UZpPRJkht73ycn2ztMnRoROu2sf+Bx75JnH0GJm/61Opnhi5l2me\n" +
                    "alavF/Og5pUk7G5p4vyk+raYVdirdBW6MzYVTntkx+AiDu6to5dkymGgU43C9omn\n" +
                    "cPxWKlKYiG6i0CiQAQJBAPHvrpGC4pvr1pw8+o1Wz7eV2s1/j6B5MwnMdEyyqUFR\n" +
                    "XMDeUcoM0uMygeXdy2pJ9+tRwNBjwOrOVwGH94Y8/n8CQQDhCkjds2LPmZjcuYmo\n" +
                    "BW4ywxt12+gIid3rvCT0L9upO37C3g2Yg4mhnlgjKVSxzByYhIAj2o7lVCOsGmec\n" +
                    "zgAxAkEA6w0qVUUMVOA0iWbVJiyJcputEKo2KHqYE5UICNwrhMI/k0JrxBnhacrQ\n" +
                    "WTu7PXDP5VhwNAY2j+oYrewjl8/6kQJBAJL5FpHEwLn5BL7TZjYYJdp9Vofo8Wfy\n" +
                    "Mr/tBu17/ChQtP8r6xE6hz7InaOJMMlWFy79CntgGIdqJkoWjKj6WWECQQCYes7u\n" +
                    "r9M3LvGtZKXB8DNmtIjD4KB9rqot4V9HoEm+rYz/PvDl76TjovufI6RvZn2K8ZiO\n" +
                    "l3m3ffOEISCImDnw\n";

    /**
     * 极光模拟用户手机号码
     */
    private String jiGuangMockPhone;

}

==> egg-user-model-2.0.4-20211209.072156-2-sources.jar: com/bxm/egg/user/properties/CommonProperties.java <==
package com.bxm.egg.user.properties;

import com.google.common.collect.Lists;
import lombok.Data;
import org.springframework.boot.context.properties.ConfigurationProperties;
import org.springframework.stereotype.Component;

import java.util.List;

/**
 * @author zhaoyadong 2019/3/9 13:41
 * @desc
 */
@Data
@Component
@ConfigurationProperties("common.config")
public class CommonProperties {


    /**
     * 创蓝闪验加密私钥
     */
    private String chuanglanPrivateKey;


    /**
     * 区域编码
     */
    private String locationCode;

    /**
     * 区域名称
     */
    private String locationName;

    /**
     * 极光appKey
     */
    private String jiGuangAppKey = "4f96a04fc41c557beea4a84e";

    /**
     * 极光密钥
     */
    private String jiGuangMasterSecret = "725e661f39c5c21e422f2d87";

    /**
     * 极光一键登录私钥
     */
    private String oneKeySecretKey =
            "MIICeAIBADANBgkqhkiG9w0BAQEFAASCAmIwggJeAgEAAoGBANStYKekQuFUoWcX\n" +
                    "MZLdPhi4qXAc45OiG43WtdUV8V1e1Kn7Bn2bGZGdKF82+JrXNQwr2Kg33LLavtll\n" +
                    "eWBFSJMTeGbP/xtdK7htldM4VdRI5AigNwNroM3/j7gqxkqKqG+1uPpRckujIOkT\n" +
                    "3HcPfAF77o7mDi5gQHT9gaPf3rZPAgMBAAECgYAFZmGN4B3SmtN+Sph3oiZxej7T\n" +
                    "GeitVvBcKZd0UZpPRJkht73ycn2ztMnRoROu2sf+Bx75JnH0GJm/61Opnhi5l2me\n" +
                    "alavF/Og5pUk7G5p4vyk+raYVdirdBW6MzYVTntkx+AiDu6to5dkymGgU43C9omn\n" +
                    "cPxWKlKYiG6i0CiQAQJBAPHvrpGC4pvr1pw8+o1Wz7eV2s1/j6B5MwnMdEyyqUFR\n" +
                    "XMDeUcoM0uMygeXdy2pJ9+tRwNBjwOrOVwGH94Y8/n8CQQDhCkjds2LPmZjcuYmo\n" +
                    "BW4ywxt12+gIid3rvCT0L9upO37C3g2Yg4mhnlgjKVSxzByYhIAj2o7lVCOsGmec\n" +
                    "zgAxAkEA6w0qVUUMVOA0iWbVJiyJcputEKo2KHqYE5UICNwrhMI/k0JrxBnhacrQ\n" +
                    "WTu7PXDP5VhwNAY2j+oYrewjl8/6kQJBAJL5FpHEwLn5BL7TZjYYJdp9Vofo8Wfy\n" +
                    "Mr/tBu17/ChQtP8r6xE6hz7InaOJMMlWFy79CntgGIdqJkoWjKj6WWECQQCYes7u\n" +
                    "r9M3LvGtZKXB8DNmtIjD4KB9rqot4V9HoEm+rYz/PvDl76TjovufI6RvZn2K8ZiO\n" +
                    "l3m3ffOEISCImDnw\n";

    /**
     * 极光模拟用户手机号码
     */
    private String jiGuangMockPhone;



    /**
     * 空头像的md5，微信的锅
     */
    private List<String> emptyHeadImgFileMd5 = Lists.newArrayList("8f8c903011d60fa9d913baa18a6af6d3");

}
